const state = {
    loadingBanks: false,
    banks: [],
    selectedBank: null,
    showBankPayment: false
}

const getters = {
    loadingBanks(state) {
        return state.loadingBanks
    },
    banks(state) {
        return state.banks
    },
    selectedBank(state) {
        return state.selectedBank
    },
    showBankPayment(state) {
        return state.showBankPayment
    }
}

const mutations = {
    setLoadingBanks(state, loading) {    
        state.loadingBanks = !!loading
    },
    setBanks(state, payload) {
        state.banks = payload
    },
    setSelectedBank(state, bankId) {
        if (!bankId) {
            return
        }

        state.selectedBank = state.banks.find(b => b.id === bankId)
    },
    toggleBankPayment(state) {
        state.showBankPayment = !state.showBankPayment
    }
}

const actions = {
    initBanks ({ commit }, payload) {
        commit('setBanks', payload)
        commit('setLoadingBanks')
    },
    toggleBankPayment({ commit }) {
        commit('toggleFooterButtonsVisibility')
        commit('toggleBankPayment')
    },
    changeBank({ commit }, bankId) {
        commit('setSelectedBank', bankId)
    },
    resetBank ({ getters, commit }) {
        if (getters.isWired) {
            commit('setLoadingBanks', true)
            commit('setBanks', [])
        }
        
        commit('setSelectedBank', null)
    }
}

export default {
    state,
    getters,
    actions,
    mutations
}