const state = {
    loadingPricelists: false,
    pricelists: [],
    showPricelists: false
}

const getters = {
    loadingPricelists(state) {
        return state.loadingPricelists
    },
    pricelists(state) {
        return state.pricelists
    },
    pricelistsForProduct(state, getters) {
        let product = getters.itemToDiscount

        if (!product) {
            return []
        }

        let companyId = getters.selectedUser.company.id
        let pricelists = []

        for (let p of state.pricelists) {
            if (p.type !== 'sale') {
                continue
            }

            for (let v of p.versions) {
                for (let i of v.items) {
                    if (i.productId !== product.id && i.productTmplId !== product.tmplId && i.categoryId !== product.categoryId) {
                        continue
                    }

                    if (!i.productId && i.productId !== companyId) {
                        continue
                    }

                    pricelists.push({
                        pricelistName: p.name,
                        versionName: v.name,
                        productPrice: product.listPrice,
                        productCost: product.standardPrice,
                        ...i
                    })
                }
            }
        }

        return pricelists
    },
    showPricelists(state) {
        return state.showPricelists
    }
}

const mutations = {
    setLoadingPricelists(state, loading) {
        state.loadingPricelists = !!loading
    },
    setPricelists(state, pricelists) {
        state.pricelists = pricelists
    },
    togglePricelists(state) {
        state.showPricelists = !state.showPricelists
    }
}

const actions = {
    initPricelists({ commit }, pricelists) {
        commit('setPricelists', pricelists)
        commit('setLoadingPricelists')
    },
    togglePricelists({ commit }) {
        commit('togglePricelists')
    },
    resetPricelist({ commit }) {
        commit('setLoadingPricelists', true)
        commit('setPricelists', [])
    }
}

export default {
    state,
    getters,
    actions,
    mutations
}